==> libssh-docs-0.10.6-1-aarch64.pkg.tar.xz: usr/share/doc/libssh/html/search/all_e.js <==
var searchData=
[
  ['f_5fbavail_0',['f_bavail',['../structsftp__statvfs__struct.html#a8d8620d4b88e9e3be113bee04ee25b19',1,'sftp_statvfs_struct']]],
  ['f_5fbfree_1',['f_bfree',['../structsftp__statvfs__struct.html#ab3721bf75407a6af8075153b514f240a',1,'sftp_statvfs_struct']]],
  ['f_5fblocks_2',['f_blocks',['../structsftp__statvfs__struct.html#a168b20e6fcac5a39588188219068aa5b',1,'sftp_statvfs_struct']]],
  ['f_5ffavail_3',['f_favail',['../structsftp__statvfs__struct.html#ab4218fab7af40f05b7c0084c4391c38f',1,'sftp_statvfs_struct']]],
  ['f_5fffree_4',['f_ffree',['../structsftp__statvfs__struct.html#a835bcc57e22a39716e2785e7268a4535',1,'sftp_statvfs_struct']]],
  ['f_5ffiles_5',['f_files',['../structsftp__statvfs__struct.html#a858796cc07c262c5137742d2a9906a7d',1,'sftp_statvfs_struct']]],
  ['f_5fflag_6',['f_flag',['../structsftp__statvfs__struct.html#abcc2c48299b8cec7715105e757a0e9a9',1,'sftp_statvfs_struct']]],
  ['f_5ffrsize_7',['f_frsize',['../structsftp__statvfs__struct.html#adb890a7fb6ee008fd246ebe93c5f3c64',1,'sftp_statvfs_struct']]],
  ['f_5ffsid_8',['f_fsid',['../structsftp__statvfs__struct.html#aefd16d855b51182773a8239f106c7709',1,'sftp_statvfs_struct']]],
  ['f_5fnamemax_9',['f_namemax',['../structsftp__statvfs__struct.html#a8e094d2dbb5e8686e8c3f7b20b14e1c9',1,'sftp_statvfs_struct']]],
  ['fe25519_10',['fe25519',['../structfe25519.html',1,'']]],
  ['features_11',['features',['../index.html#main-additional-features',1,'Additional Features'],['../index.html#main-features',1,'Features']]],
  ['file_20from_20the_20remote_20computer_12',['Reading a file from the remote computer',['../libssh_tutor_sftp.html#sftp_read',1,'']]],
  ['file_20to_20the_20remote_20computer_13',['Copying a file to the remote computer',['../libssh_tutor_sftp.html#sftp_write',1,'']]],
  ['file_20transfer_20protocol_20sftp_14',['Secure Shell File Transfer Protocol (SFTP)',['../index.html#main-rfc-sftp',1,'']]],
  ['files_20and_20directories_15',['files and directories',['../libssh_tutor_scp.html#scp_write',1,'Creating files and directories'],['../libssh_tutor_scp.html#scp_read',1,'Reading files and directories']]],
  ['forwarding_16',['forwarding',['../libssh_tutor_forwarding.html#forwarding_direct',1,'Direct port forwarding'],['../libssh_tutor_forwarding.html#forwarding_reverse',1,'Reverse port forwarding']]],
  ['forwarding_20connections_17',['Forwarding connections',['../libssh_tutor_forwarding.html#forwarding_connections',1,'']]],
  ['forwarding_20connections_20tunnel_18',['Chapter 7: Forwarding connections (tunnel)',['../libssh_tutor_forwarding.html',1,'libssh_tutorial']]],
  ['forwarding_20with_20libssh_19',['forwarding with libssh',['../libssh_tutor_forwarding.html#libssh_direct',1,'Doing direct port forwarding with libssh'],['../libssh_tutor_forwarding.html#libssh_reverse',1,'Doing reverse port forwarding with libssh']]],
  ['freebsd_20ci_20instance_20',['Install a FreeBSD CI instance',['../md_README_8gitlab_8freebsd.html',1,'']]],
  ['from_20the_20remote_20computer_21',['Reading a file from the remote computer',['../libssh_tutor_sftp.html#sftp_read',1,'']]],
  ['from_20the_20remote_20server_22',['Receiving full directory trees from the remote server',['../libssh_tutor_scp.html#scp_recursive_read',1,'']]],
  ['full_20directory_20trees_20from_20the_20remote_20server_23',['Receiving full directory trees from the remote server',['../libssh_tutor_scp.html#scp_recursive_read',1,'']]],
  ['full_20directory_20trees_20to_20the_20remote_20server_24',['Copying full directory trees to the remote server',['../libssh_tutor_scp.html#scp_recursive_write',1,'']]],
  ['functions_25',['functions',['../group__libssh__auth.html',1,'The SSH authentication functions'],['../group__libssh__buffer.html',1,'The SSH buffer functions'],['../group__libssh__channel.html',1,'The SSH channel functions'],['../group__libssh__error.html',1,'The SSH error functions'],['../group__libssh__misc.html',1,'The SSH helper functions'],['../group__libssh__log.html',1,'The SSH logging functions'],['../group__libssh__messages.html',1,'The SSH message functions'],['../group__libssh__poll.html',1,'The SSH poll functions'],['../group__libssh__scp.html',1,'The SSH scp functions'],['../group__libssh__session.html',1,'The SSH session functions'],['../group__libssh__socket.html',1,'The SSH socket functions.'],['../group__libssh__string.html',1,'The SSH string functions'],['../group__libssh__threads.html',1,'The SSH threading functions']]]
];

==> libssh-docs-0.10.6-2-aarch64.pkg.tar.xz: usr/share/doc/libssh/html/search/all_e.js <==
var searchData=
[
  ['f_5fbavail_0',['f_bavail',['../structsftp__statvfs__struct.html#a8d8620d4b88e9e3be113bee04ee25b19',1,'sftp_statvfs_struct']]],
  ['f_5fbfree_1',['f_bfree',['../structsftp__statvfs__struct.html#ab3721bf75407a6af8075153b514f240a',1,'sftp_statvfs_struct']]],
  ['f_5fblocks_2',['f_blocks',['../structsftp__statvfs__struct.html#a168b20e6fcac5a39588188219068aa5b',1,'sftp_statvfs_struct']]],
  ['f_5ffavail_3',['f_favail',['../structsftp__statvfs__struct.html#ab4218fab7af40f05b7c0084c4391c38f',1,'sftp_statvfs_struct']]],
  ['f_5fffree_4',['f_ffree',['../structsftp__statvfs__struct.html#a835bcc57e22a39716e2785e7268a4535',1,'sftp_statvfs_struct']]],
  ['f_5ffiles_5',['f_files',['../structsftp__statvfs__struct.html#a858796cc07c262c5137742d2a9906a7d',1,'sftp_statvfs_struct']]],
  ['f_5fflag_6',['f_flag',['../structsftp__statvfs__struct.html#abcc2c48299b8cec7715105e757a0e9a9',1,'sftp_statvfs_struct']]],
  ['f_5ffrsize_7',['f_frsize',['../structsftp__statvfs__struct.html#adb890a7fb6ee008fd246ebe93c5f3c64',1,'sftp_statvfs_struct']]],
  ['f_5ffsid_8',['f_fsid',['../structsftp__statvfs__struct.html#aefd16d855b51182773a8239f106c7709',1,'sftp_statvfs_struct']]],
  ['f_5fnamemax_9',['f_namemax',['../structsftp__statvfs__struct.html#a8e094d2dbb5e8686e8c3f7b20b14e1c9',1,'sftp_statvfs_struct']]],
  ['fe25519_10',['fe25519',['../structfe25519.html',1,'']]],
  ['features_11',['Features',['../index.html#main-additional-features',1,'Additional Features'],['../index.html#main-features',1,'Features']]],
  ['file_20from_20the_20remote_20computer_12',['Reading a file from the remote computer',['../libssh_tutor_sftp.html#sftp_read',1,'']]],
  ['file_20to_20the_20remote_20computer_13',['Copying a file to the remote computer',['../libssh_tutor_sftp.html#sftp_write',1,'']]],
  ['file_20transfer_20protocol_20sftp_14',['Secure Shell File Transfer Protocol (SFTP)',['../index.html#main-rfc-sftp',1,'']]],
  ['files_20and_20directories_15',['Files and directories',['../libssh_tutor_scp.html#scp_write',1,'Creating files and directories'],['../libssh_tutor_scp.html#scp_read',1,'Reading files and directories']]],
  ['forwarding_16',['Forwarding',['../libssh_tutor_forwarding.html#forwarding_direct',1,'Direct port forwarding'],['../libssh_tutor_forwarding.html#forwarding_reverse',1,'Reverse port forwarding']]],
  ['forwarding_20connections_17',['Forwarding connections',['../libssh_tutor_forwarding.html#forwarding_connections',1,'']]],
  ['forwarding_20connections_20tunnel_18',['Chapter 7: Forwarding connections (tunnel)',['../libssh_tutor_forwarding.html',1,'libssh_tutorial']]],
  ['forwarding_20with_20libssh_19',['Forwarding with libssh',['../libssh_tutor_forwarding.html#libssh_direct',1,'Doing direct port forwarding with libssh'],['../libssh_tutor_forwarding.html#libssh_reverse',1,'Doing reverse port forwarding with libssh']]],
  ['freebsd_20ci_20instance_20',['Install a FreeBSD CI instance',['../md_README_8gitlab_8freebsd.html',1,'']]],
  ['from_20the_20remote_20computer_21',['Reading a file from the remote computer',['../libssh_tutor_sftp.html#sftp_read',1,'']]],
  ['from_20the_20remote_20server_22',['Receiving full directory trees from the remote server',['../libssh_tutor_scp.html#scp_recursive_read',1,'']]],
  ['full_20directory_20trees_20from_20the_20remote_20server_23',['Receiving full directory trees from the remote server',['../libssh_tutor_scp.html#scp_recursive_read',1,'']]],
  ['full_20directory_20trees_20to_20the_20remote_20server_24',['Copying full directory trees to the remote server',['../libssh_tutor_scp.html#scp_recursive_write',1,'']]],
  ['functions_25',['functions',['../group__libssh__auth.html',1,'The SSH authentication functions'],['../group__libssh__buffer.html',1,'The SSH buffer functions'],['../group__libssh__channel.html',1,'The SSH channel functions'],['../group__libssh__error.html',1,'The SSH error functions'],['../group__libssh__misc.html',1,'The SSH helper functions'],['../group__libssh__log.html',1,'The SSH logging functions'],['../group__libssh__messages.html',1,'The SSH message functions'],['../group__libssh__poll.html',1,'The SSH poll functions'],['../group__libssh__scp.html',1,'The SSH scp functions'],['../group__libssh__session.html',1,'The SSH session functions'],['../group__libssh__socket.html',1,'The SSH socket functions.'],['../group__libssh__string.html',1,'The SSH string functions'],['../group__libssh__threads.html',1,'The SSH threading functions']]]
];
